==> haskell-versions-5.0.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-versions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 versions
version:              5.0.1
visibility:           public
id:                   versions-5.0.1-2rZLiQe8CjALI9dXvofg6
key:                  versions-5.0.1-2rZLiQe8CjALI9dXvofg6
license:              BSD-3-Clause
maintainer:           colin@fosskers.ca
author:               Colin Woodbury
homepage:             https://github.com/fosskers/versions
synopsis:             Types and parsers for software version numbers.
description:
    A library for parsing and comparing software version numbers. We like to give
    version numbers to our software in a myriad of ways. Some ways follow strict
    guidelines for incrementing and comparison. Some follow conventional wisdom
    and are generally self-consistent. Some are just plain asinine. This library
    provides a means of parsing and comparing /any/ style of versioning, be it a
    nice Semantic Version like this:

    > 1.2.3-r1+git123

    ...or a monstrosity like this:

    > 2:10.2+0.0093r3+1-1

    Please switch to <http://semver.org Semantic Versioning> if you aren'\''t
    currently using it. It provides consistency in version incrementing and has
    the best constraints on comparisons.

    This library implements version @2.0.0@ of the SemVer spec.

category:             Data
abi:                  8ddc61f230a5c3917a82011a00be050e
exposed:              True
exposed-modules:      Data.Versions
import-dirs:          /usr/lib/ghc-9.0.2/site-local/versions-5.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/versions-5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/versions-5.0.1
hs-libraries:         HSversions-5.0.1-2rZLiQe8CjALI9dXvofg6
depends:
    base-4.15.1.0 deepseq-1.4.5.0
    hashable-1.3.5.0-9wAI1WS8YgI32PWp14SUvr
    megaparsec-9.2.0-DOqqM4bOk8V75QdsXnG6rD
    parser-combinators-1.3.0-FL5bcA6sX4a2ejs4tDtkjB text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-versions/html/versions.haddock
haddock-html:         /usr/share/doc/haskell-versions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-versions-5.0.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-versions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 versions
version:              5.0.1
visibility:           public
id:                   versions-5.0.1-9KvsNz41u18E7A8CIRI48X
key:                  versions-5.0.1-9KvsNz41u18E7A8CIRI48X
license:              BSD-3-Clause
maintainer:           colin@fosskers.ca
author:               Colin Woodbury
homepage:             https://github.com/fosskers/versions
synopsis:             Types and parsers for software version numbers.
description:
    A library for parsing and comparing software version numbers. We like to give
    version numbers to our software in a myriad of ways. Some ways follow strict
    guidelines for incrementing and comparison. Some follow conventional wisdom
    and are generally self-consistent. Some are just plain asinine. This library
    provides a means of parsing and comparing /any/ style of versioning, be it a
    nice Semantic Version like this:

    > 1.2.3-r1+git123

    ...or a monstrosity like this:

    > 2:10.2+0.0093r3+1-1

    Please switch to <http://semver.org Semantic Versioning> if you aren'\''t
    currently using it. It provides consistency in version incrementing and has
    the best constraints on comparisons.

    This library implements version @2.0.0@ of the SemVer spec.

category:             Data
abi:                  b1627a3c85ea7d8c3f2a005cf25969ed
exposed:              True
exposed-modules:      Data.Versions
import-dirs:          /usr/lib/ghc-9.0.2/site-local/versions-5.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/versions-5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/versions-5.0.1
hs-libraries:         HSversions-5.0.1-9KvsNz41u18E7A8CIRI48X
depends:
    base-4.15.1.0 deepseq-1.4.5.0
    hashable-1.3.5.0-8uEDmbS1YdCBqBDHH62nE1
    megaparsec-9.2.0-EDj2Dq3EC325n1pQ5lRkij
    parser-combinators-1.3.0-FL5bcA6sX4a2ejs4tDtkjB text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-versions/html/versions.haddock
haddock-html:         /usr/share/doc/haskell-versions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
